module.exports = defineTest({
	description: 'wraps simplified expressions that have become callees if necessary'
});
